@@ -6,8 +6,9 @@ import time
 import threading
 
 headers = {
-    "user-agent": "Mozilla/5.0 (Linux; Android 6.0; Nexus 5 Build/MRA58N) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/93.0.4577.63 Mobile Safari/537.366"
+    "user-agent": "Mozilla/5.0 (Linux; Android 6.0; Nexus 5 Build/MRA58N) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/98.0.4758.80 Mobile Safari/537.36"
 }
+
 errors = []
 err_msg_network = "Make Sure You Have An Internet Connection."
 
@@ -42,7 +43,6 @@ def handle_pagination(username, url):
 
     try:
         response = session.get(url, headers=headers)
-
         soup = BeautifulSoup(response.content, "lxml")
 
         try:
@@ -129,18 +129,25 @@ def handle_pagination(username, url):
                          license_, stars, forked_by)
 
         try:
-            if soup.find(attrs={"data-test-selector": "pagination"}):
-                div = soup.find(
-                    attrs={"data-test-selector": "pagination"}).select("a")
+            # if soup.find(attrs={"data-test-selector": "pagination"}):
+            #     div = soup.find(
+            #         attrs={"data-test-selector": "pagination"}).select("a")
 
-                for a in div:
-                    if a.text == "Next":
-                        url = a['href']
+            #     for a in div:
+            #         if a.text == "Next":
+            #             url = a['href']
+            #     errors.clear()
+            #     handle_pagination(username, url)
+            if soup.find('a', {"class": "next_page"}):
+                a = soup.find('a', {"class": "next_page"})
+                if a.text == "Next":
+                    url = "https://github.com"+a['href']
                 errors.clear()
                 handle_pagination(username, url)
+
         except Exception as e:
             errors.append(e)
-    except:
+    except Exception as e:
         errors.append(err_msg_network)
         exit(0)
 
@@ -149,8 +156,9 @@ def loader(url, username):
     try:
         response = session.get(url, headers=headers)
         soup = BeautifulSoup(response.content, "lxml")
+        # print(soup)
         total_projects = soup.find(
-            "a", class_="UnderlineNav-item selected").select('span')[0].text.strip()
+            "span", class_="Counter").text.strip()
         print(f"Hello {username}\n")
 
         print(f"{total_projects} repositories found.")
